@@ -12,8 +12,8 @@ test_that("x is a tibble", {
   expect_is(x, "tbl")
 })
 
-test_that("error message", {
-  expect_error(get_db_topics(branch = "Master"))
+test_that("message", {
+  expect_message(get_db_topics(branch = "Master"))
 })
 
 fn <- c("ennet_topics_2021-01-17_00:54:48.csv")
@@ -52,11 +52,11 @@ test_that("x is a tibble", {
   expect_is(x, "tbl")
 })
 
-x <- create_db_topics_hourlies(.date = Sys.Date())
+#x <- create_db_topics_hourlies(.date = Sys.Date())
 
-test_that("x is a tibble", {
-  expect_is(x, "tbl")
-})
+#test_that("x is a tibble", {
+#  expect_is(x, "tbl")
+#})
 
 test_that("expect error", {
   expect_error(create_db_topics_hourlies(.date = NA))
